BiometricFingerprintPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • BiometricFingerprintPlatform
Implementers

Constructors

BiometricFingerprintPlatform()
Constructs a BiometricFingerprintPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance BiometricFingerprintPlatform
The default instance of BiometricFingerprintPlatform to use.
getter/setter pair
isEnabled Future<bool>
Returns true if device can use biometric.
no setter
type Future<BiometricType>
Get the BiometricType available on the device.
no setter

Static Methods

initAuthentication({required String biometricKey, required String message, String messageKey = '', String title = 'Biometric Authentication', String subtitle = 'Enter biometric credentials to proceed', String description = '', String negativeButtonText = 'CANCEL', bool confirmationRequired = false, bool deviceCredentialAllowed = false}) Future<BiometricResult>
Encrypt message using biometric.